package cn.yyxx.eyuangame.core.impl.center.fragment

import android.content.Context
import android.graphics.Color
import android.os.Bundle
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import androidx.fragment.app.Fragment
import cn.yyxx.eyuangame.core.entity.ClickType
import cn.yyxx.eyuangame.core.impl.center.MemberActivity
import cn.yyxx.eyuangame.core.ui.EventEditText
import cn.yyxx.support.ResUtils

/**
 * @author #Suyghur.
 * Created on 2021/06/30
 */
class BindPhoneFragment : Fragment(), View.OnClickListener {

    private lateinit var mView: View
    private lateinit var memberImpl: MemberActivity

    private lateinit var ivReturn: ImageView
    private lateinit var eetPhone: EventEditText
    private lateinit var eetCaptcha: EventEditText
    private lateinit var btnCaptCha: Button
    private lateinit var btnConfirm: Button

    private lateinit var tvArea: TextView
    private lateinit var ivArrow: ImageView

    private lateinit var rlAreaList: RelativeLayout
    private lateinit var llAreaList: LinearLayout
    private lateinit var svAreaList: ScrollView

    private val areaList = mutableListOf<String>()

    private var imgUp = 0
    private var imgDown = 0

    private var code = ""

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        super.onCreateView(inflater, container, savedInstanceState)
        memberImpl = requireActivity() as MemberActivity
        mView = layoutInflater.inflate(ResUtils.getResId(requireActivity(), "yyxx_member_bind_phone", "layout"), container, false)
        initView(mView)
        return mView
    }

    private fun initView(view: View) {

        imgUp = ResUtils.getResId(context, "yyxx_pack_up_white_img", "drawable")
        imgDown = ResUtils.getResId(context, "yyxx_pack_down_white_img", "drawable")

        ivReturn = view.findViewById(ResUtils.getResId(requireActivity(), "yyxx_iv_return", "id"))
        ivReturn.apply {
            tag = ClickType.ACTION_RETURN
            setOnClickListener(this@BindPhoneFragment)
        }

        eetPhone = view.findViewById(ResUtils.getResId(requireActivity(), "yyxx_eet_phone", "id"))
        eetPhone.editText.hint = ResUtils.getResString(requireActivity(), "yyxx_hint_forget_phone")

        eetCaptcha = view.findViewById(ResUtils.getResId(requireActivity(), "yyxx_eet_captcha", "id"))
        eetCaptcha.editText.hint = ResUtils.getResString(requireActivity(), "yyxx_hint_bind_phone_captcha")

        btnCaptCha = view.findViewById(ResUtils.getResId(requireActivity(), "yyxx_btn_captcha", "id"))
        btnCaptCha.apply {
            tag = ClickType.ACTION_GET_CAPTCHA
            setOnClickListener(this@BindPhoneFragment)
        }

        btnConfirm = view.findViewById(ResUtils.getResId(requireActivity(), "yyxx_btn_confirm", "id"))
        btnConfirm.apply {
            tag = ClickType.ACTION_CONFIRM
            setOnClickListener(this@BindPhoneFragment)
        }

        rlAreaList = view.findViewById(ResUtils.getResId(context, "yyxx_rl_area_list", "id"))
        rlAreaList.visibility = View.GONE
        llAreaList = view.findViewById(ResUtils.getResId(context, "yyxx_ll_area_list", "id"))
        svAreaList = view.findViewById(ResUtils.getResId(context, "yyxx_sv_area_list", "id"))


        tvArea = view.findViewById(ResUtils.getResId(context, "yyxx_tv_area", "id"))
        ivArrow = view.findViewById(ResUtils.getResId(context, "yyxx_iv_arrow", "id"))
        ivArrow.setOnClickListener {
            changeAreaList()
        }

        autoFillAreaList(requireActivity())
    }

    private fun autoFillAreaList(context: Context) {
        if (areaList.size == 0) {
            //默认4个地区
            areaList.add("86")
            //香港
            areaList.add("862")
            //澳门
            areaList.add("853")
            //台湾
            areaList.add("886")
        }
        initAreaList(context)
    }

    private fun initAreaList(context: Context) {
        llAreaList.removeAllViews()
        //单行高
        var height = 100
        tvArea.apply {
            height = if (layoutParams != null) {
                layoutParams!!.height
            } else {
                100
            }
        }
        //ScrollView高度
        var maxHeight = 0
        areaList.apply {
            maxHeight = if (size < 2) {
                size * height
            } else {
                2 * height
            }
        }
        //循环添加列
        areaList.apply {
            for (i in indices) {
                val areaCode = this[i]
                //添加线
                val line = View(context)
                line.layoutParams = LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, 2)
                line.setBackgroundColor(Color.parseColor("#E6FFFFFF"))
                llAreaList.apply {
                    if (childCount > 0) {
                        addView(line)
                    }
                }
                //添加区号
                val item = LayoutInflater.from(context).inflate(ResUtils.getResId(context, "yyxx_area_list_item", "layout"), null)
                item?.apply {
                    val tvAreaCode = findViewById<TextView>(ResUtils.getResId(context, "yyxx_tv_area", "id"))
                    tvAreaCode.gravity = Gravity.CENTER
                    tvAreaCode.text = areaCode
                    code = areaCode
                    setOnClickListener(OnItemClick(areaCode))
                    layoutParams = LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, height)
                    llAreaList.addView(this, llAreaList.childCount)
                }
            }
        }
        svAreaList.layoutParams = RelativeLayout.LayoutParams(RelativeLayout.LayoutParams.MATCH_PARENT, maxHeight)
    }


    private fun changeAreaList() {
        if (rlAreaList.visibility == View.GONE) {
            ivArrow.setBackgroundResource(imgUp)
            rlAreaList.visibility = View.VISIBLE
        } else {
            ivArrow.setBackgroundResource(imgDown)
            rlAreaList.visibility = View.GONE
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        areaList.clear()
        rlAreaList.visibility = View.GONE
    }

    override fun onClick(v: View?) {
        v?.apply {
            when (tag as Int) {
                ClickType.ACTION_RETURN -> requireActivity().onBackPressed()
            }
        }
    }

    /**
     * 账号列表item点击事件
     */
    private inner class OnItemClick(val areaCode: String) : View.OnClickListener {
        override fun onClick(v: View?) {
            tvArea.apply {
                changeAreaList()
                tvArea.text = areaCode
            }
        }
    }
}